Class: MagicBell::Client
- Inherits:
-
Object
- Object
- MagicBell::Client
- Includes:
- Notifications
- Defined in:
- lib/magicbell/client.rb,
lib/magicbell/client/notifications.rb
Defined Under Namespace
Modules: Notifications
Instance Method Summary collapse
-
#connection ⇒ Object
Returns an authenticated connection object which can be used to make requests.
Methods included from Notifications
Instance Method Details
#connection ⇒ Object
Returns an authenticated connection object which can be used to make requests
9 10 11 |
# File 'lib/magicbell/client.rb', line 9 def connection @connection ||= Faraday.new(url: MagicBell.api_host) end |